package com.cweb.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.pay.util.sdk.WXPayConstants;
import com.hai.common.utils.*;
import com.hai.config.QianZhuConfig;
import com.hai.config.TuanYouConfig;
import com.hai.entity.*;
import com.hai.model.HighMerchantModel;
import com.hai.model.HighMerchantStoreModel;
import com.hai.model.ResponseData;
import com.hai.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.*;

/**
 * @Auther: 胡锐
 * @Description:
 * @Date: 2021/3/26 23:08
 */
@Controller
@RequestMapping(value = "/test")
@Api(value = "订单接口")
public class HighTestController {

    private static Logger log = LoggerFactory.getLogger(HighTestController.class);

    @Resource
    private HighMerchantService highMerchantService;

    @Resource
    private HighMerchantStoreService highMerchantStoreService;

    @Resource
    private HighGasOilPriceService highGasOilPriceService;


    @RequestMapping(value = "/initTYMerchantStore", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "根据")
    public ResponseData initTYMerchantStore(@RequestParam(name = "merchantId", required = true) Long merchantId) {
        try {

            HighMerchantModel merchant = highMerchantService.getMerchantById(merchantId);
            if (merchant == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未找到商户");
            }

            JSONObject jsonObject = TuanYouConfig.queryGasInfoListByPage(1, 10);
            JSONObject resultObject = jsonObject.getObject("result", JSONObject.class);
            JSONArray jsonArray = resultObject.getJSONArray("gasInfoList");
            HighMerchantStore highMerchantStore;
            HighGasOilPrice highGasOilPrice;
            for (Object gasObject : jsonArray) {
                JSONObject object = JSONObject.parseObject(JSONObject.toJSONString(gasObject));
                if (object.getInteger("gasStatus") == 1) {
                    HighMerchantStoreModel store = highMerchantStoreService.getMerchantStoreByKey(object.getString("gasId"));
                    if (store != null) {
                        store.setType(1);
                        store.setMerchantId(merchant.getId());
                        store.setCompanyId(merchant.getCompanyId());
                        store.setStoreKey(object.getString("gasId"));
                        store.setStoreName(object.getString("gasName"));
                        store.setStoreLogo(object.getString("gasLogoSmall"));
                        store.setRegionId(object.getLong("provinceCode"));
                        store.setRegionName(object.getString("provinceName"));
                        store.setAddress(object.getString("gasAddress"));
                        store.setLongitude(object.getString("gasAddressLongitude"));
                        store.setLatitude(object.getString("gasAddressLatitude"));
                        store.setOperatorId(0L);
                        store.setOperatorName("系统创建");
                        store.setUpdateTime(new Date());
                        store.setExt1(object.getString("gasSourceId"));
                        highMerchantStoreService.updateMerchantStoreDetail(store);

                        JSONArray oilPriceList = object.getJSONArray("oilPriceList");
                        for (Object oilPrice : oilPriceList) {
                            JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                            // 查询门店油号
                            highGasOilPrice = highGasOilPriceService.getGasOilPriceByStoreAndOilNo(store.getId(), oilPriceObject.getInteger("oilNo"));
                            if(highGasOilPrice == null) {
                                highGasOilPrice.setMerchantStoreId(store.getId());
                                highGasOilPrice.setOilNo(oilPriceObject.getInteger("oilNo"));
                                highGasOilPrice.setOilNoName(oilPriceObject.getString("oilNoName"));
                                highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("priceVip"));
                                highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("priceGun"));
                                highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("priceOfficial"));
                                highGasOilPrice.setOilType(oilPriceObject.getInteger("oilType"));
                                highGasOilPrice.setOilTypeName(oilPriceObject.getString("oilTypeName"));
                            } else {
                                highGasOilPrice.setMerchantStoreId(store.getId());
                                highGasOilPrice.setOilNo(oilPriceObject.getInteger("oilNo"));
                                highGasOilPrice.setOilNoName(oilPriceObject.getString("oilNoName"));
                                highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("priceVip"));
                                highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("priceGun"));
                                highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("priceOfficial"));
                                highGasOilPrice.setOilType(oilPriceObject.getInteger("oilType"));
                                highGasOilPrice.setOilTypeName(oilPriceObject.getString("oilTypeName"));
                            }
                            highGasOilPriceService.editGasOilPrice(highGasOilPrice);
                        }
                    } else {
                        highMerchantStore = new HighMerchantStore();
                        highMerchantStore.setType(1);
                        highMerchantStore.setMerchantId(merchant.getId());
                        highMerchantStore.setCompanyId(merchant.getCompanyId());
                        highMerchantStore.setStoreKey(object.getString("gasId"));
                        highMerchantStore.setStoreName(object.getString("gasName"));
                        highMerchantStore.setStoreLogo(object.getString("gasLogoSmall"));
                        highMerchantStore.setRegionId(object.getLong("provinceCode"));
                        highMerchantStore.setRegionName(object.getString("provinceName"));
                        highMerchantStore.setAddress(object.getString("gasAddress"));
                        highMerchantStore.setLongitude(object.getString("gasAddressLongitude"));
                        highMerchantStore.setLatitude(object.getString("gasAddressLatitude"));
                        highMerchantStore.setStatus(1);
                        highMerchantStore.setOperatorId(0L);
                        highMerchantStore.setOperatorName("系统创建");
                        highMerchantStore.setCreateTime(new Date());
                        highMerchantStore.setUpdateTime(new Date());
                        highMerchantStore.setExt1(object.getString("gasSourceId"));
                        HighMerchantStoreModel merchantStoreModel = new HighMerchantStoreModel();
                        BeanUtils.copyProperties(highMerchantStore, merchantStoreModel);
                        highMerchantStoreService.insertMerchantStore(merchantStoreModel);

                        JSONArray oilPriceList = object.getJSONArray("oilPriceList");
                        for (Object oilPrice : oilPriceList) {
                            JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                            highGasOilPrice = new HighGasOilPrice();
                            highGasOilPrice.setMerchantStoreId(merchantStoreModel.getId());
                            highGasOilPrice.setOilNo(oilPriceObject.getInteger("oilNo"));
                            highGasOilPrice.setOilNoName(oilPriceObject.getString("oilNoName"));
                            highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("priceVip"));
                            highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("priceGun"));
                            highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("priceOfficial"));
                            highGasOilPrice.setOilType(oilPriceObject.getInteger("oilType"));
                            highGasOilPrice.setOilTypeName(oilPriceObject.getString("oilTypeName"));
                            highGasOilPriceService.editGasOilPrice(highGasOilPrice);
                        }
                    }
                }
            }
            return ResponseMsgUtil.success(jsonArray);
        } catch (Exception e) {
            log.error("HighOrderController --> getOrderById() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value = "/test1", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "测试")
    public ResponseData test1() {
        try {
            return ResponseMsgUtil.success(QianZhuConfig.payKfcOrder("20210712232301218036376"));
        } catch (Exception e) {
            log.error("HighOrderController --> getOrderById() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }
    @RequestMapping(value = "/test2", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "测试")
    public ResponseData test2() {
        try {
            return ResponseMsgUtil.success(QianZhuConfig.getKfcOrderByOrderNo("20210712230130341045846"));
        } catch (Exception e) {
            log.error("HighOrderController --> getOrderById() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
